@@ -33,7 +33,7 @@ class CLIDispatcher(EnabledExtensionManager):
     """
 
     def __init__(self):
-        super(CLIDispatcher, self).__init__('avocado.plugins.cli')
+        super().__init__('avocado.plugins.cli')
 
 
 class CLICmdDispatcher(EnabledExtensionManager):
@@ -46,7 +46,7 @@ class CLICmdDispatcher(EnabledExtensionManager):
     """
 
     def __init__(self):
-        super(CLICmdDispatcher, self).__init__('avocado.plugins.cli.cmd')
+        super().__init__('avocado.plugins.cli.cmd')
 
 
 class JobPrePostDispatcher(EnabledExtensionManager):
@@ -59,19 +59,19 @@ class JobPrePostDispatcher(EnabledExtensionManager):
     """
 
     def __init__(self):
-        super(JobPrePostDispatcher, self).__init__('avocado.plugins.job.prepost')
+        super().__init__('avocado.plugins.job.prepost')
 
 
 class ResultDispatcher(EnabledExtensionManager):
 
     def __init__(self):
-        super(ResultDispatcher, self).__init__('avocado.plugins.result')
+        super().__init__('avocado.plugins.result')
 
 
 class ResultEventsDispatcher(EnabledExtensionManager):
 
     def __init__(self, config):
-        super(ResultEventsDispatcher, self).__init__(
+        super().__init__(
             'avocado.plugins.result_events',
             invoke_kwds={'config': config})
 
@@ -79,7 +79,7 @@ class ResultEventsDispatcher(EnabledExtensionManager):
 class VarianterDispatcher(EnabledExtensionManager):
 
     def __init__(self):
-        super(VarianterDispatcher, self).__init__('avocado.plugins.varianter')
+        super().__init__('avocado.plugins.varianter')
 
     def __getstate__(self):
         """
@@ -101,31 +101,32 @@ class VarianterDispatcher(EnabledExtensionManager):
         self.extensions = state.get("extensions")
 
     def map_method_with_return(self, method_name, *args, **kwargs):
-        return super(VarianterDispatcher, self).map_method_with_return(
+        return super().map_method_with_return(
             method_name, deepcopy=False, *args, **kwargs)
 
     def map_method_with_return_copy(self, method_name, *args, **kwargs):
         """
         The same as map_method_with_return, but use copy.deepcopy on each passed arg
         """
-        return super(VarianterDispatcher, self).map_method_with_return(
+        return super().map_method_with_return(
             method_name, deepcopy=True, *args, **kwargs)
 
 
 class RunnerDispatcher(EnabledExtensionManager):
 
     def __init__(self):
-        super(RunnerDispatcher, self).__init__('avocado.plugins.runner')
+        super().__init__('avocado.plugins.runner')
 
 
 class InitDispatcher(EnabledExtensionManager):
 
     def __init__(self):
-        super(InitDispatcher, self).__init__('avocado.plugins.init')
+        super().__init__('avocado.plugins.init')
 
 
 class SpawnerDispatcher(EnabledExtensionManager):
 
-    def __init__(self, config=None):
-        super(SpawnerDispatcher, self).__init__('avocado.plugins.spawner',
-                                                invoke_kwds={'config': config})
+    def __init__(self, config=None, job=None):
+        super().__init__('avocado.plugins.spawner',
+                         invoke_kwds={'job': job,
+                                      'config': config})
