@@ -20,7 +20,8 @@ from avocado.core import output
 from avocado.core.settings import settings
 from avocado.utils import genio
 from avocado.utils import path as utils_path
-from avocado.utils import software_manager, sysinfo
+from avocado.utils import sysinfo
+from avocado.utils.software_manager import manager
 
 log = logging.getLogger("avocado.sysinfo")
 
@@ -164,7 +165,7 @@ class SysInfo:
             log.debug(e.args[0])
 
     def _get_installed_packages(self):
-        sm = software_manager.SoftwareManager()
+        sm = manager.SoftwareManager()
         installed_pkgs = sm.list_all()
         self._installed_pkgs = installed_pkgs
         return installed_pkgs
