@@ -19,6 +19,7 @@ framework tests.
 """
 
 import asyncio
+import functools
 import inspect
 import io
 import logging
@@ -30,6 +31,7 @@ import sys
 import tempfile
 import time
 import unittest
+import warnings
 from difflib import unified_diff
 
 from avocado.core import exceptions, output, parameters, sysinfo, tapparser
@@ -328,6 +330,7 @@ class Test(unittest.TestCase, TestData):
         self.__fail_reason = None
         self.__fail_class = None
         self.__traceback = None
+        self.__skip_test = False
 
         # Are initialized lazily
         self.__cache_dirs = None
@@ -575,7 +578,7 @@ class Test(unittest.TestCase, TestData):
         state['class_name'] = self.__class__.__name__
         state['params'] = [(path, key, value)
                            for path, key, value
-                           in self.__params.iteritems()]  # pylint: disable=W1620
+                           in self.__params.iteritems()]
         return state
 
     def _register_log_file_handler(self, logger, formatter, filename,
@@ -703,43 +706,40 @@ class Test(unittest.TestCase, TestData):
                 return True
         return False
 
-    def _run_avocado(self):
+    def _run_test(self):
         """
-        Auxiliary method to run_avocado.
+        Auxiliary method to run setup and test method.
         """
+        self._tag_start()
         testMethod = getattr(self, self._testMethodName)
         if self._config.get("run.test_runner") != 'nrunner':
             self._start_logging()
         if self.__sysinfo_enabled:
             self.__sysinfo_logger.start()
-        test_exception = None
-        cleanup_exception = None
-        stdout_check_exception = None
-        stderr_check_exception = None
         skip_test_condition = getattr(testMethod, '__skip_test_condition__', False)
         skip_test_condition_negate = getattr(testMethod, '__skip_test_condition_negate__', False)
         if skip_test_condition:
             if callable(skip_test_condition):
                 if skip_test_condition_negate:
-                    skip_test = not bool(skip_test_condition(self))
+                    self.__skip_test = not bool(skip_test_condition(self))
                 else:
-                    skip_test = bool(skip_test_condition(self))
+                    self.__skip_test = bool(skip_test_condition(self))
             else:
                 if skip_test_condition_negate:
-                    skip_test = not bool(skip_test_condition)
+                    self.__skip_test = not bool(skip_test_condition)
                 else:
-                    skip_test = bool(skip_test_condition)
+                    self.__skip_test = bool(skip_test_condition)
         else:
-            skip_test = bool(skip_test_condition)
+            self.__skip_test = bool(skip_test_condition)
         try:
-            if skip_test is False:
+            if self.__skip_test is False:
                 self.__phase = 'SETUP'
                 self.setUp()
         except exceptions.TestSkipError as details:
-            skip_test = True
+            self.__skip_test = True
             stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
             raise exceptions.TestSkipError(details)
-        except exceptions.TestCancel as details:
+        except exceptions.TestCancel:
             stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
             raise
         except:  # Old-style exceptions are not inherited from Exception()
@@ -754,7 +754,7 @@ class Test(unittest.TestCase, TestData):
                     loop.run_until_complete(testMethod())
                 else:
                     testMethod()
-            except exceptions.TestCancel as details:
+            except exceptions.TestCancel:
                 stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
                 raise
             except:  # Old-style exceptions are not inherited from Exception() pylint: disable=W0702
@@ -762,51 +762,38 @@ class Test(unittest.TestCase, TestData):
                 details = sys.exc_info()[1]
                 if not isinstance(details, Exception):  # Avoid passing nasty exc
                     details = exceptions.TestError("%r: %s" % (details, details))
-                test_exception = details
                 self.log.debug("Local variables:")
                 local_vars = inspect.trace()[1][0].f_locals
                 for key, value in local_vars.items():
                     self.log.debug(' -> %s %s: %s', key, type(value), value)
-        finally:
-            try:
-                if skip_test is False:
-                    self.__phase = 'TEARDOWN'
-                    self.tearDown()
-            except exceptions.TestSkipError as details:
-                stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
-                skip_illegal_msg = ('Using skip decorators in tearDown() '
-                                    'is not allowed in '
-                                    'avocado, you must fix your '
-                                    'test. Original skip exception: %s' %
-                                    details)
-                raise exceptions.TestError(skip_illegal_msg)
-            except exceptions.TestCancel as details:
-                stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
-                raise
-            except:  # avoid old-style exception failures pylint: disable=W0702
-                stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
-                details = sys.exc_info()[1]
-                cleanup_exception = exceptions.TestSetupFail(details)
-
-        whiteboard_file = os.path.join(self.logdir, 'whiteboard')
-        genio.write_file(whiteboard_file, self.whiteboard)
-
-        # pylint: disable=E0702
-        if test_exception is not None:
-            raise test_exception
-        elif cleanup_exception is not None:
-            raise cleanup_exception
-        elif stdout_check_exception is not None:
-            raise stdout_check_exception
-        elif stderr_check_exception is not None:
-            raise stderr_check_exception
-        elif self.__log_warn_used:
-            raise exceptions.TestWarn("Test passed but there were warnings "
-                                      "during execution. Check the log for "
-                                      "details.")
+                raise details
 
         self.__status = 'PASS'
 
+    def _tearDown(self):
+        """
+        Auxiliary method to run tearDown.
+        """
+        try:
+            if self.__skip_test is False:
+                self.__phase = 'TEARDOWN'
+                self.tearDown()
+        except exceptions.TestSkipError as details:
+            stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
+            skip_illegal_msg = ('Using skip decorators in tearDown() '
+                                'is not allowed in '
+                                'avocado, you must fix your '
+                                'test. Original skip exception: %s' %
+                                details)
+            raise exceptions.TestError(skip_illegal_msg)
+        except exceptions.TestCancel:
+            stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
+            raise
+        except:  # avoid old-style exception failures pylint: disable=W0702
+            stacktrace.log_exc_info(sys.exc_info(), logger=LOG_JOB)
+            details = sys.exc_info()[1]
+            raise exceptions.TestSetupFail(details)
+
     def _setup_environment_variables(self):
         os.environ['AVOCADO_VERSION'] = VERSION
         if self.basedir is not None:
@@ -819,16 +806,14 @@ class Test(unittest.TestCase, TestData):
         if self.__sysinfo_enabled:
             os.environ['AVOCADO_TEST_SYSINFODIR'] = self.__sysinfodir
 
-    def run_avocado(self):
-        """
-        Wraps the run method, for execution inside the avocado runner.
-
-        :result: Unused param, compatibility with :class:`unittest.TestCase`.
-        """
-        self._setup_environment_variables()
+    def _catch_test_status(self, method):
+        """Wrapper around test methods for catching and logging failures."""
         try:
-            self._tag_start()
-            self._run_avocado()
+            method()
+            if self.__log_warn_used:
+                raise exceptions.TestWarn("Test passed but there were warnings "
+                                          "during execution. Check the log for "
+                                          "details.")
         except exceptions.TestBaseException as detail:
             self.__status = detail.status
             self.__fail_class = detail.__class__.__name__
@@ -852,13 +837,25 @@ class Test(unittest.TestCase, TestData):
                                       "traceback for details.")
             for e_line in tb_info:
                 self.log.error(e_line)
-        finally:
-            if self.__sysinfo_enabled:
-                self.__sysinfo_logger.end(self.__status)
-            self.__phase = 'FINISHED'
-            self._tag_end()
-            self._report()
-            self.log.info("")
+
+    def run_avocado(self):
+        """
+        Wraps the run method, for execution inside the avocado runner.
+
+        :result: Unused param, compatibility with :class:`unittest.TestCase`.
+        """
+        self._setup_environment_variables()
+        self._catch_test_status(self._run_test)
+        self._catch_test_status(self._tearDown)
+        whiteboard_file = os.path.join(self.logdir, 'whiteboard')
+        genio.write_file(whiteboard_file, self.whiteboard)
+        if self.__sysinfo_enabled:
+            self.__sysinfo_logger.end(self.__status)
+        self.__phase = 'FINISHED'
+        self._tag_end()
+        self._report()
+        self.log.info("")
+        if self._config.get("run.test_runner") != 'nrunner':
             self._stop_logging()
 
     def _report(self):
@@ -877,37 +874,67 @@ class Test(unittest.TestCase, TestData):
             self.log.info("%s %s", self.status,
                           self.name)
 
-    def fail(self, message=None):  # pylint: disable=W0221
+    def _deprecate_params_message(func):  # pylint: disable=E0213
+        """ This decorator helps to deprecate parameter 'message' and
+        replace it with 'msg'.
+        """
+
+        @functools.wraps(func)
+        def wrapper(*args, **kwargs):
+            msg = None
+            message = None
+
+            if 'msg' in kwargs:
+                msg = kwargs.get('msg')
+            elif args:
+                msg = args[0]
+
+            if 'message' in kwargs:
+                message = kwargs.get('message')
+                if msg:
+                    warnings.warn("Please favor parameter 'msg' and do not use "
+                                  "it with the parameter 'message'",
+                                  DeprecationWarning)
+
+                else:
+                    warnings.warn("The parameter 'message' has been deprecated."
+                                  " Please use 'msg' instead", DeprecationWarning)
+
+            actual_message = msg or message
+            return func(actual_message)
+        return wrapper
+
+    @staticmethod
+    @_deprecate_params_message
+    def fail(msg=None):
         """
         Fails the currently running test.
 
         After calling this method a test will be terminated and have its status
         as FAIL.
 
-        :param message: an optional message that will be recorded in the logs
-        :type message: str
-        :warning message: This parameter will changed name to "msg" in the next
-                          LTS release because of lint W0221
+        :param msg: an optional message that will be recorded in the logs
+        :type msg: str
         """
-        raise exceptions.TestFail(message)
+        raise exceptions.TestFail(msg)
 
     @staticmethod
-    def error(message=None):  # pylint: disable=W0221
+    @_deprecate_params_message
+    def error(msg=None):
         """
         Errors the currently running test.
 
         After calling this method a test will be terminated and have its status
         as ERROR.
 
-        :param message: an optional message that will be recorded in the logs
-        :type message: str
-        :warning message: This parameter will changed name to "msg" in the next
-                          LTS release because of lint W0221
+        :param msg: an optional message that will be recorded in the logs
+        :type msg: str
         """
-        raise exceptions.TestError(message)
+        raise exceptions.TestError(msg)
 
     @staticmethod
-    def cancel(message=None):  # pylint: disable=W0221
+    @_deprecate_params_message
+    def cancel(msg=None):
         """
         Cancels the test.
 
@@ -917,12 +944,10 @@ class Test(unittest.TestCase, TestData):
         test method, avocado will mark your test status as ERROR, and
         instruct you to fix your test in the error message.
 
-        :param message: an optional message that will be recorded in the logs
-        :type message: str
-        :warning message: This parameter will changed name to "msg" in the next
-                          LTS release because of lint W0221
+        :param msg: an optional message that will be recorded in the logs
+        :type msg: str
         """
-        raise exceptions.TestCancel(message)
+        raise exceptions.TestCancel(msg)
 
     def fetch_asset(self, name, asset_hash=None, algorithm=None,
                     locations=None, expire=None, find_only=False,
@@ -1016,9 +1041,8 @@ class SimpleTest(Test):
         if executable is None:
             executable = name.name
         self._filename = executable
-        super(SimpleTest, self).__init__(name=name, params=params,
-                                         base_logdir=base_logdir,
-                                         config=config)
+        super().__init__(name=name, params=params,
+                         base_logdir=base_logdir, config=config)
         # Access workdir to initialize it, given that it's lazy
         _ = self.workdir
 
@@ -1070,7 +1094,7 @@ class SimpleTest(Test):
         """
         try:
             test_params = dict([(str(key), str(val)) for _, key, val in
-                                self.params.iteritems()])  # pylint: disable=W1620
+                                self.params.iteritems()])
 
             input_encoding = self._config.get('core.input_encoding')
             result = process.run(self._command,
@@ -1133,7 +1157,7 @@ class TapTest(SimpleTest):
         try:
             test_params = {
                 str(key): str(val)
-                for _, key, val in self.params.iteritems()  # pylint: disable=W1620
+                for _, key, val in self.params.iteritems()
             }
 
             input_encoding = self._config.get('core.input_encoding')
@@ -1192,7 +1216,7 @@ class MockingTest(Test):
         This class substitutes other classes. Let's just ignore the remaining
         arguments and only set the ones supported by avocado.Test
         """
-        super_kwargs = dict()
+        super_kwargs = {}
         args = list(reversed(args))
         for arg in ["methodName", "name", "params", "base_logdir", "config",
                     "runner_queue"]:
@@ -1202,7 +1226,7 @@ class MockingTest(Test):
                 super_kwargs[arg] = args.pop()
         # The methodName might not exist, make sure it's self.test
         super_kwargs["methodName"] = "test"
-        super(MockingTest, self).__init__(**super_kwargs)
+        super().__init__(**super_kwargs)
 
     def test(self):
         pass
@@ -1233,11 +1257,11 @@ class DryRunTest(MockingTest):
             self._filename = kwargs.pop('modulePath')
         if self._filename is None:
             self._filename = kwargs["name"].name
-        super(DryRunTest, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def setUp(self):
         self.log.info("Test params:")
-        for path, key, value in self.params.iteritems():  # pylint: disable=W1620
+        for path, key, value in self.params.iteritems():
             self.log.info("%s:%s ==> %s", path, key, value)
         self.cancel('Test cancelled due to --dry-run')
 
