@@ -52,11 +52,10 @@ class FilterSet(set):
         return item
 
     def add(self, item):
-        return super(FilterSet, self).add(self.__normalize(item))
+        return super().add(self.__normalize(item))
 
     def update(self, items):
-        return super(FilterSet, self).update([self.__normalize(item)
-                                              for item in items])
+        return super().update([self.__normalize(item) for item in items])
 
     def __str__(self):
         return ('FilterSet([%s])'
@@ -68,7 +67,7 @@ class TreeEnvironment(dict):
     """ TreeNode environment with values, origins and filters """
 
     def __init__(self):
-        super(TreeEnvironment, self).__init__()     # values
+        super().__init__()     # values
         self.origin = {}    # origins of the values
         self.filter_only = FilterSet()   # list of filter_only
         self.filter_out = FilterSet()    # list of filter_out
@@ -480,13 +479,13 @@ def tree_view(root, verbose=None, use_utf8=None):
     if use_utf8 is None:
         use_utf8 = locale.getdefaultlocale()[1] == 'UTF-8'
     if use_utf8:
-        charset = {'DoubleDown': u' \u2551   ',
-                   'DoubleDownRight': u' \u2560\u2550\u2550 ',
-                   'DoubleRight': u' \u255a\u2550\u2550 ',
-                   'Down': u' \u2503   ',
-                   'DownRight': u' \u2523\u2501\u2501 ',
-                   'Right': u' \u2517\u2501\u2501 ',
-                   'Value': u'\u2192 '}
+        charset = {'DoubleDown': ' \u2551   ',
+                   'DoubleDownRight': ' \u2560\u2550\u2550 ',
+                   'DoubleRight': ' \u255a\u2550\u2550 ',
+                   'Down': ' \u2503   ',
+                   'DownRight': ' \u2523\u2501\u2501 ',
+                   'Right': ' \u2517\u2501\u2501 ',
+                   'Value': '\u2192 '}
     else:   # ASCII fallback
         charset = {'Down': ' |   ',
                    'DownRight': ' |-- ',
