@@ -67,7 +67,7 @@ class Run(CLICmd):
 
         :param parser: Main test runner parser.
         """
-        parser = super(Run, self).configure(parser)
+        parser = super().configure(parser)
 
         settings.add_argparser_to_option(namespace='resolver.references',
                                          nargs='*',
