@@ -5,7 +5,7 @@ import sys
 from avocado.core.job import Job
 from avocado.core.suite import TestSuite
 
-config = {'run.references': ['examples/tests/sleeptest.py:SleepTest.test'],
+config = {'resolver.references': ['examples/tests/sleeptest.py:SleepTest.test'],
           'run.dict_variants': [
               {'sleep_length': "0.5"},
               {'sleep_length': "1.0"}
