@@ -5,7 +5,7 @@ import sys
 from avocado.core.job import Job
 from avocado.core.suite import TestSuite
 
-config = {'run.references': ['examples/tests/sleeptest.py:SleepTest.test'],
+config = {'resolver.references': ['examples/tests/sleeptest.py:SleepTest.test'],
           'json.variants.load': 'examples/tests/sleeptest.py.data/sleeptest.json'}
 
 suite = TestSuite.from_config(config)
