@@ -11,8 +11,8 @@ statuses = ["FAIL", "CANCEL"]"""
 class TestLogsUI(TestCaseTmpDir):
 
     def setUp(self):
-        super(TestLogsUI, self).setUp()
-        with open(os.path.join(self.tmpdir.name, 'config'), 'w') as config:
+        super().setUp()
+        with open(os.path.join(self.tmpdir.name, 'config'), 'w', encoding='utf-8') as config:
             config.write(CONFIG)
 
     def test(self):
@@ -34,7 +34,7 @@ class TestLogsUI(TestCaseTmpDir):
 class TestLogsFilesUI(TestCaseTmpDir):
 
     def setUp(self):
-        super(TestLogsFilesUI, self).setUp()
+        super().setUp()
         self.config_file = script.TemporaryScript(
             'avocado.conf',
             "[job.output.testlogs]\n"
@@ -58,7 +58,7 @@ class TestLogsFilesUI(TestCaseTmpDir):
                          r'Failure to access log file.*DOES_NOT_EXIST"')
 
     def tearDown(self):
-        super(TestLogsFilesUI, self).tearDown()
+        super().tearDown()
         self.config_file.remove()
 
 
@@ -70,7 +70,7 @@ class TestLogging(TestCaseTmpDir):
                     (AVOCADO, self.tmpdir.name, pass_test))
         process.run(cmd_line)
         log_file = os.path.join(self.tmpdir.name, 'latest', 'job.log')
-        with open(log_file, 'r') as fp:
+        with open(log_file, 'r', encoding='utf-8') as fp:
             log = fp.read()
         self.assertIn('passtest.py:PassTest.test: STARTED', log)
         self.assertIn('passtest.py:PassTest.test: PASS', log)
