@@ -185,7 +185,7 @@ class RunnerOperationTest(TestCaseTmpDir):
         process.run(cmd_line)
         # Also check whether jobdata contains correct parameter paths
         variants = open(os.path.join(self.tmpdir.name, "latest", "jobdata",
-                                     "variants-1.json")).read()
+                                     "variants-1.json"), encoding='utf-8').read()
         expected = '[{"paths": ["/run/*"], "variant_id": null, "variant": [["/", []]]}]'
         self.assertEqual(variants, expected)
 
@@ -407,7 +407,7 @@ class RunnerOperationTest(TestCaseTmpDir):
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         json_path = os.path.join(self.tmpdir.name, 'latest', 'results.json')
-        with open(json_path) as json_file:
+        with open(json_path, encoding='utf-8') as json_file:
             result_json = json.load(json_file)
         output = result.stdout
         expected_rc = exit_codes.AVOCADO_JOB_INTERRUPTED
@@ -566,9 +566,9 @@ class RunnerOperationTest(TestCaseTmpDir):
                          "Avocado did not return rc %d:\n%s" % (expected_rc, result))
 
         json_path = os.path.join(self.tmpdir.name, 'latest', 'results.json')
-        with open(json_path) as json_file:
+        with open(json_path, encoding='utf-8') as json_file:
             result_json = json.load(json_file)
-        with open(result_json['tests'][0]['logfile'], 'r+b') as test_log_file:
+        with open(result_json['tests'][0]['logfile'], 'r+b') as test_log_file:  # pylint: disable=W1514
             test_log = test_log_file.read()
 
         self.assertIn(b"PARAMS (key=sleep_length, path=*, default=1) => '0.01'",
@@ -592,7 +592,7 @@ class RunnerOperationTest(TestCaseTmpDir):
             test_log_dir = glob.glob(os.path.join(self.tmpdir.name, 'job-*',
                                                   'test-results', '1-*'))[0]
             test_log_path = os.path.join(test_log_dir, 'debug.log')
-            with open(test_log_path, 'rb') as test_log:
+            with open(test_log_path, 'rb') as test_log:  # pylint: disable=W1514
                 self.assertNotIn(b'SHOULD NOT BE ON debug.log', test_log.read())
 
     def test_store_logging_stream(self):
@@ -608,7 +608,7 @@ class RunnerOperationTest(TestCaseTmpDir):
                                      '.test_plant_organic',
                                      'avocado.test.progress')
         self.assertTrue(os.path.exists(progress_info))
-        with open(progress_info) as file:
+        with open(progress_info, encoding='utf-8') as file:
             stream_line = file.readline()
             self.assertIn('INFO | 1-examples/tests/logging_streams.py:'
                           'Plant.test_plant_organic: preparing soil on row 0',
@@ -634,7 +634,7 @@ class DryRunTest(TestCaseTmpDir):
         for i in range(number_of_tests):
             test = result['tests'][i]
             self.assertEqual(test['fail_reason'],
-                             u'Test cancelled due to --dry-run')
+                             'Test cancelled due to --dry-run')
 
 
 class RunnerHumanOutputTest(TestCaseTmpDir):
@@ -686,9 +686,9 @@ class RunnerHumanOutputTest(TestCaseTmpDir):
 class RunnerSimpleTest(TestCaseTmpDir):
 
     def setUp(self):
-        super(RunnerSimpleTest, self).setUp()
+        super().setUp()
         self.pass_script = script.TemporaryScript(
-            u'\u00e1 \u00e9 \u00ed \u00f3 \u00fa',
+            '\u00e1 \u00e9 \u00ed \u00f3 \u00fa',
             "#!/bin/sh\ntrue",
             'avocado_simpletest_functional')
         self.pass_script.save()
@@ -805,13 +805,13 @@ class RunnerSimpleTest(TestCaseTmpDir):
     def tearDown(self):
         self.pass_script.remove()
         self.fail_script.remove()
-        super(RunnerSimpleTest, self).tearDown()
+        super().tearDown()
 
 
 class RunnerSimpleTestStatus(TestCaseTmpDir):
 
     def setUp(self):
-        super(RunnerSimpleTestStatus, self).setUp()
+        super().setUp()
         self.config_file = script.TemporaryScript('avocado.conf',
                                                   "[simpletests.status]\n"
                                                   "warn_regex = ^WARN$\n"
@@ -865,14 +865,14 @@ class RunnerSimpleTestStatus(TestCaseTmpDir):
         skip2_script.remove()
 
     def tearDown(self):
-        super(RunnerSimpleTestStatus, self).tearDown()
+        super().tearDown()
         self.config_file.remove()
 
 
 class RunnerReferenceFromConfig(TestCaseTmpDir):
 
     def setUp(self):
-        super(RunnerReferenceFromConfig, self).setUp()
+        super().setUp()
         self.config_file = script.TemporaryScript('avocado.conf',
                                                   "[resolver]\n"
                                                   "references = ['/bin/true']\n")
@@ -888,14 +888,14 @@ class RunnerReferenceFromConfig(TestCaseTmpDir):
                          "Avocado did not return rc %d:\n%s" % (expected_rc, result))
 
     def tearDown(self):
-        super(RunnerReferenceFromConfig, self).tearDown()
+        super().tearDown()
         self.config_file.remove()
 
 
 class RunnerSimpleTestFailureFields(TestCaseTmpDir):
 
     def setUp(self):
-        super(RunnerSimpleTestFailureFields, self).setUp()
+        super().setUp()
         self.config_file = script.TemporaryScript(
             'avocado.conf',
             "[simpletests.status]\n"
@@ -915,7 +915,7 @@ class RunnerSimpleTestFailureFields(TestCaseTmpDir):
         self.assertNotIn("Exited with status: '1'", result.stdout_text)
 
     def tearDown(self):
-        super(RunnerSimpleTestFailureFields, self).tearDown()
+        super().tearDown()
         self.config_file.remove()
 
 
@@ -942,48 +942,9 @@ class PluginsTest(TestCaseTmpDir):
                          result.stdout)
 
     def test_list_error_output(self):
-        cmd_line = '%s list --loader sbrubles' % AVOCADO
+        cmd_line = '%s list sbrubles' % AVOCADO
         result = process.run(cmd_line, ignore_status=True)
-        self.assertIn(b"Unable to resolve reference", result.stderr)
-
-    def test_list_no_file_loader(self):
-        cmd_line = ("%s --verbose list --loaders tap.TAP "
-                    "--loader "
-                    "-- this-wont-be-matched" % AVOCADO)
-        result = process.run(cmd_line, ignore_status=True)
-        self.assertEqual(result.exit_status, exit_codes.AVOCADO_ALL_OK,
-                         "Avocado did not return rc %d:\n%s"
-                         % (exit_codes.AVOCADO_ALL_OK, result))
-        exp = (b"Type    Test                 Tag(s)\n"
-               b"MISSING this-wont-be-matched\n\n"
-               b"TEST TYPES SUMMARY\n"
-               b"==================\n"
-               b"missing: 1\n")
-        self.assertEqual(exp, result.stdout, "Stdout mismatch:\n%s\n\n%s"
-                         % (exp, result))
-
-    def test_list_verbose_tags(self):
-        """
-        Runs list verbosely and check for tag related output
-        """
-        test = script.make_script(os.path.join(self.tmpdir.name, 'test.py'),
-                                  VALID_PYTHON_TEST_WITH_TAGS)
-        cmd_line = ("%s --verbose list "
-                    "--loader "
-                    "--loaders file -- %s" % (AVOCADO, test))
-        result = process.run(cmd_line, ignore_status=True)
-        self.assertEqual(result.exit_status, exit_codes.AVOCADO_ALL_OK,
-                         "Avocado did not return rc %d:\n%s"
-                         % (exit_codes.AVOCADO_ALL_OK, result))
-        stdout_lines = result.stdout_text.splitlines()
-        self.assertIn("Tag(s)", stdout_lines[0])
-        full_test_name = "%s:MyTest.test" % test
-        self.assertEqual("INSTRUMENTED %s BIG_TAG_NAME" % full_test_name,
-                         stdout_lines[1])
-        self.assertIn("TEST TYPES SUMMARY", stdout_lines)
-        self.assertIn("instrumented: 1", stdout_lines)
-        self.assertIn("TEST TAGS SUMMARY", stdout_lines)
-        self.assertEqual("big_tag_name: 1", stdout_lines[-1])
+        self.assertEqual("", result.stdout_text)
 
     def test_plugin_list(self):
         cmd_line = '%s plugins' % AVOCADO
@@ -1115,7 +1076,7 @@ class PluginsXunitTest(TestCaseTmpDir):
     @unittest.skipUnless(SCHEMA_CAPABLE,
                          'Unable to validate schema due to missing xmlschema library')
     def setUp(self):
-        super(PluginsXunitTest, self).setUp()
+        super().setUp()
         junit_xsd = os.path.join(os.path.dirname(__file__),
                                  os.path.pardir, ".data", 'jenkins-junit.xsd')
         self.xml_schema = xmlschema.XMLSchema(junit_xsd)
