@@ -124,14 +124,14 @@ if __name__ == '__main__':
 class ProcessTest(TestCaseTmpDir):
 
     def setUp(self):
-        super(ProcessTest, self).setUp()
+        super().setUp()
         self.fake_vmstat = os.path.join(self.tmpdir.name, 'vmstat')
-        with open(self.fake_vmstat, 'w') as fake_vmstat_obj:
+        with open(self.fake_vmstat, 'w', encoding='utf-8') as fake_vmstat_obj:
             fake_vmstat_obj.write(FAKE_VMSTAT_CONTENTS)
         os.chmod(self.fake_vmstat, DEFAULT_MODE)
 
         self.fake_uptime = os.path.join(self.tmpdir.name, 'uptime')
-        with open(self.fake_uptime, 'w') as fake_uptime_obj:
+        with open(self.fake_uptime, 'w', encoding='utf-8') as fake_uptime_obj:
             fake_uptime_obj.write(FAKE_UPTIME_CONTENTS)
         os.chmod(self.fake_uptime, DEFAULT_MODE)
 
@@ -195,13 +195,13 @@ class FileLockTest(TestCaseTmpDir):
         """
         :avocado: tags=parallel:1
         """
-        # Calculate the timeout
+        # Calculate the timeout based on t_100_iter + 2e-5*players
         start = time.monotonic()
-        for _ in range(50):
+        for _ in range(100):
             with FileLock(self.tmpdir.name):
                 pass
         timeout = 0.02 + (time.monotonic() - start)
-        players = 500
+        players = 1000
         pool = multiprocessing.Pool(players)
         args = [(self.tmpdir.name, players, timeout)] * players
         try:
