@@ -149,7 +149,7 @@ class TestClassTestUnit(unittest.TestCase):
                           base_logdir=self.tmpdir.name)
         content = 'expected content\n'
         content_path = os.path.join(tst.logdir, 'content')
-        with open(content_path, 'w') as produced:
+        with open(content_path, 'w', encoding='utf-8') as produced:
             produced.write(content)
         self.assertTrue(tst._check_reference(content_path,
                                              content_path,
@@ -200,7 +200,7 @@ class TestClassTest(unittest.TestCase):
         whiteboard_file = os.path.join(
             self.tst_instance_pass.logdir, 'whiteboard')
         self.assertTrue(os.path.isfile(whiteboard_file))
-        with open(whiteboard_file, 'r') as whiteboard_file_obj:
+        with open(whiteboard_file, 'r', encoding='utf-8') as whiteboard_file_obj:
             whiteboard_contents = whiteboard_file_obj.read().strip()
             self.assertTrue(whiteboard_contents, 'foo')
 
